@@ -32,7 +32,7 @@
 #include <fors_dfs.h>
 #include <fors_utils.h>
 #include <moses.h>
-#include "fiera_config.h"
+#include "fors_ccd_config.h"
 #include "mosca_image.h"
 #include "statistics.h"
 #include "fors_overscan.h"
@@ -226,7 +226,7 @@ void fors_bias(cpl_frameset *frames, const cpl_parameterlist *parameters)
     cpl_propertylist * bias_header = 
             cpl_propertylist_load(cpl_frame_get_filename(
                     cpl_frameset_get_position(bias_frames, 0)), 0);
-    mosca::fiera_config bias_ccd_config(bias_header);
+    fors::fiera_config bias_ccd_config(bias_header);
     cpl_propertylist_delete(bias_header);
     assure( !cpl_error_get_code(), return, "Could not get instrument setting" );
 
