@@ -28,8 +28,59 @@
 #include "fors_ccd_config.h"
 #include "fiera_config.h"
 
+namespace fors 
+{
 
-std::auto_ptr<mosca::fiera_config>  fors_ccd_config_read
+fiera_config::fiera_config(const cpl_propertylist * header) :
+mosca::fiera_config(header)
+{
+    if(m_chip_id == "CCID20-14-5-3")
+    {
+        if(m_binning_factor_x == 1 && m_binning_factor_y == 1)
+        {
+            m_port_configs[0].prescan_region.set_lly(2067);
+            m_port_configs[0].prescan_region.set_ury(2067);
+        }
+        else if(m_binning_factor_x == 2 && m_binning_factor_y == 2)
+        {
+            m_port_configs[0].prescan_region.set_lly(1033);
+            m_port_configs[0].prescan_region.set_ury(1033);
+        }
+    }
+    else if(m_chip_id == "CCID20-14-5-6")
+    {
+        m_port_configs[0].prescan_region.set_lly(0);
+        m_port_configs[0].prescan_region.set_ury(0);
+    }
+    else if(m_chip_id == "Norma III")
+    {
+        if(m_binning_factor_x == 1 && m_binning_factor_y == 1)
+        {
+            m_port_configs[0].prescan_region.set_lly(2067);
+            m_port_configs[0].prescan_region.set_ury(2067);
+        }
+        else if(m_binning_factor_x == 2 && m_binning_factor_y == 2)
+        {
+            m_port_configs[0].prescan_region.set_lly(1033);
+            m_port_configs[0].prescan_region.set_ury(1033);
+        }
+    }
+    else if(m_chip_id == "Marlene")
+    {
+        m_port_configs[0].prescan_region.set_lly(0);
+        m_port_configs[0].prescan_region.set_ury(0);
+    }
+}
+
+fiera_config::fiera_config()
+{
+}
+
+fiera_config::~fiera_config()
+{
+}
+
+std::auto_ptr<fors::fiera_config>  ccd_config_read
 (const cpl_frame * source, const cpl_frame * bias_frame)
 {
     cpl_errorstate   error_prevstate = cpl_errorstate_get();
@@ -37,21 +88,21 @@ std::auto_ptr<mosca::fiera_config>  fors_ccd_config_read
     cpl_propertylist *header      = NULL;
     header = cpl_propertylist_load(cpl_frame_get_filename(source), 0);
     if (header == NULL) 
-        return std::auto_ptr<mosca::fiera_config>(0);
+        return std::auto_ptr<fors::fiera_config>(0);
 
-    std::auto_ptr<mosca::fiera_config> 
-        ccd_config(new mosca::fiera_config(header));
+    std::auto_ptr<fors::fiera_config> 
+        ccd_config(new fors::fiera_config(header));
     cpl_propertylist_delete(header);
     if(!cpl_errorstate_is_equal(error_prevstate))
-        return std::auto_ptr<mosca::fiera_config>(0);
+        return std::auto_ptr<fors::fiera_config>(0);
     
     /* Update RON estimation from bias */
     cpl_propertylist * master_bias_header =
        cpl_propertylist_load(cpl_frame_get_filename(bias_frame), 0);
-    fors_update_ccd_ron(*ccd_config, master_bias_header);
+    fors::update_ccd_ron(*ccd_config, master_bias_header);
     cpl_propertylist_delete(master_bias_header);
     if(!cpl_errorstate_is_equal(error_prevstate))
-        return std::auto_ptr<mosca::fiera_config>(0);
+        return std::auto_ptr<fors::fiera_config>(0);
     
     return ccd_config;
 }
@@ -63,24 +114,24 @@ std::auto_ptr<mosca::fiera_config>  fors_ccd_config_read
  * CCD configuration of that frame.
  * TODO: Documentation
  */
-std::auto_ptr<mosca::fiera_config> fors_ccd_settings_equal
+std::auto_ptr<fors::fiera_config> ccd_settings_equal
 (const cpl_frameset * fset)
 {
     int iframe;
-    std::auto_ptr<mosca::fiera_config> reference_config;
+    std::auto_ptr<fors::fiera_config> reference_config;
     if(cpl_frameset_get_size(fset) < 1)
         return reference_config;
     cpl_propertylist * ref_header =
        cpl_propertylist_load(cpl_frame_get_filename(
               cpl_frameset_get_position_const(fset, 0)), 0);
-    reference_config.reset(new mosca::fiera_config(ref_header));
+    reference_config.reset(new fors::fiera_config(ref_header));
 
     for(iframe = 1; iframe < cpl_frameset_get_size(fset); ++iframe)
     {
         cpl_propertylist * other_header = 
             cpl_propertylist_load(cpl_frame_get_filename(
                   cpl_frameset_get_position_const(fset, iframe)), 0);
-        mosca::fiera_config other_config = mosca::fiera_config(other_header);
+        fors::fiera_config other_config = fors::fiera_config(other_header);
 
         cpl_propertylist_delete(other_header);
         if(*reference_config != other_config)
@@ -91,8 +142,8 @@ std::auto_ptr<mosca::fiera_config> fors_ccd_settings_equal
     return reference_config;
 }
 
-void fors_update_ccd_ron(mosca::ccd_config ccd_config, 
-                         cpl_propertylist * master_bias_header)
+void update_ccd_ron(mosca::ccd_config ccd_config, 
+                    cpl_propertylist * master_bias_header)
 {
     if(master_bias_header == NULL)
         std::invalid_argument("empty header");
@@ -112,3 +163,7 @@ void fors_update_ccd_ron(mosca::ccd_config ccd_config,
     }
 }
 
+} /* namespace fors */
+
+
+
