@@ -130,8 +130,8 @@ void fors_dark(cpl_frameset *frames, const cpl_parameterlist *parameters)
     
     /* Find raw */
     dark_frames = fors_frameset_extract(frames, DARK);
-    std::auto_ptr<mosca::fiera_config> dark_ccd_config = 
-            fors_ccd_settings_equal(dark_frames);
+    std::auto_ptr<fors::fiera_config> dark_ccd_config = 
+            fors::ccd_settings_equal(dark_frames);
 
     assure( cpl_frameset_get_size(dark_frames) > 0, return, 
             "No %s provided", DARK);
@@ -146,7 +146,7 @@ void fors_dark(cpl_frameset *frames, const cpl_parameterlist *parameters)
     cpl_propertylist * master_bias_header =
        cpl_propertylist_load(cpl_frame_get_filename(
                cpl_frameset_get_position(master_bias_frame, 0)), 0);
-    fors_update_ccd_ron(*dark_ccd_config, master_bias_header);
+    fors::update_ccd_ron(*dark_ccd_config, master_bias_header);
     cpl_propertylist_delete(master_bias_header);
     assure( !cpl_error_get_code(), return, "Could not get RON from master bias"
             " (missing QC DET OUT? RON keywords)");
