@@ -470,9 +470,7 @@ int dfs_get_parameter_int(cpl_parameterlist *parlist, const char *name,
         }
     }
 
-    cpl_msg_info(func, "%s:", alias);
-    cpl_msg_info(func, "%s: %d",
-                 cpl_parameter_get_help(param), cpl_parameter_get_int(param));
+    cpl_msg_info(func, "%s: %d", alias, cpl_parameter_get_int(param));
 
     return cpl_parameter_get_int(param);
 
@@ -568,9 +566,7 @@ double dfs_get_parameter_double(cpl_parameterlist *parlist,
         }
     }
 
-    cpl_msg_info(func, "%s:", alias);
-    cpl_msg_info(func, "%s: %f",
-                 cpl_parameter_get_help(param), cpl_parameter_get_double(param));
+    cpl_msg_info(func, "%s: %f", alias, cpl_parameter_get_double(param));
 
     return cpl_parameter_get_double(param);
 
@@ -667,9 +663,7 @@ const char *dfs_get_parameter_string(cpl_parameterlist *parlist,
         }
     }
 
-    cpl_msg_info(func, "%s:", alias);
-    cpl_msg_info(func, "%s: %s", cpl_parameter_get_help(param), 
-                 cpl_parameter_get_string(param));
+    cpl_msg_info(func, "%s: %s", alias, cpl_parameter_get_string(param));
 
     return cpl_parameter_get_string(param);
 
@@ -776,12 +770,10 @@ int dfs_get_parameter_bool(cpl_parameterlist *parlist, const char *name,
     value = cpl_parameter_get_bool(param);
 
     if (value) {
-        cpl_msg_info(func, "%s:", alias);
-        cpl_msg_info(func, "%s: TRUE", cpl_parameter_get_help(param));
+        cpl_msg_info(func, "%s: TRUE", alias);
     }
     else {
-        cpl_msg_info(func, "%s:", alias);
-        cpl_msg_info(func, "%s: FALSE", cpl_parameter_get_help(param));
+        cpl_msg_info(func, "%s: FALSE", alias);
     }
 
     return value;
