@@ -276,8 +276,8 @@ fors_extract_method_new(                    const cpl_parameterlist *parameters,
     cpl_free((void *)name); name = NULL;
     cpl_msg_indent_less();
 
-    assure( !cpl_error_get_code(), return NULL, NULL );
-    assure( method != NULL, return NULL, NULL );
+    assure( !cpl_error_get_code(), {cpl_free(em); return NULL;}, NULL );
+    assure( method != NULL, {cpl_free(em); return NULL;}, NULL );
 
     if (strcmp(method, "sex") == 0) {
         em->method = SEX;
