@@ -175,10 +175,16 @@ int fors::flat_normaliser::mos_normalise
     xlow = 1;
     xhig = nx;
     m_wave_profiles.clear();
+    
     for (i = 0; i < nslits; i++) {
 
         if (length[i] == 0)
+        {
+            std::vector<float> empty_sed(nx, 0.);
+            m_wave_profiles.push_back(empty_sed);
+            m_wave_profiles_norm.push_back(1.);
             continue;
+        }
 
         /*
          * We DON'T write:
@@ -215,8 +221,11 @@ int fors::flat_normaliser::mos_normalise
                                       fit_threshold, slit_spa_norm_profile,
                                       slit_disp_norm_profile);
 
+        //Get a position around the middle of the slit with a valid wave calib
+        int middle_slit = get_middle_slit_valid_calib(wave_cal, yhig, ylow);
+
         //Get the pixel of the waveref at the middle of the slit
-        double pix_waveref = wave_cal.get_pixel((yhig + ylow) / 2.,
+        double pix_waveref = wave_cal.get_pixel(middle_slit,
                                                 wave_cal.get_refwave());
         int pix_waveref_left = (int)std::floor(pix_waveref);
         int pix_waveref_rigth = (int)std::ceil(pix_waveref);
@@ -228,8 +237,12 @@ int fors::flat_normaliser::mos_normalise
         for(size_t i_prof = 0; i_prof < slit_disp_norm_profile.size(); i_prof++)
             slit_disp_norm_profile[i_prof] /= prof_val_waveref;
 
+        //The normalisation factor is divided by the slit length.
+        double prof_waveref_length = prof_val_waveref / 
+                                     slit_spa_norm_profile.size();
+
         m_wave_profiles.push_back(slit_disp_norm_profile);
-        m_wave_profiles_norm.push_back(prof_val_waveref);
+        m_wave_profiles_norm.push_back(prof_waveref_length);
         
         cpl_image * exslit = normslit.get_cpl_image();
         
@@ -472,8 +485,12 @@ int fors::flat_normaliser::lss_normalise
     for(size_t i_prof = 0; i_prof < slit_disp_norm_profile.size(); i_prof++)
         slit_disp_norm_profile[i_prof] /= prof_val_waveref;
 
+    //The normalisation factor is divided by the slit length.
+    double prof_waveref_length = prof_val_waveref / 
+                                 flat.size_spatial();
+
     m_wave_profiles.push_back(slit_disp_norm_profile);
-    m_wave_profiles_norm.push_back(prof_val_waveref);
+    m_wave_profiles_norm.push_back(prof_waveref_length);
 
 
     //Finally divide by the smoothed version of the flat.
@@ -485,6 +502,36 @@ int fors::flat_normaliser::lss_normalise
     return 0;
 }
 
+//TODO: This is probably not the best place for this. It is a static function in
+//order to be used directly by vimos_science_map_disp_profile
+int fors::flat_normaliser::get_middle_slit_valid_calib
+(const mosca::wavelength_calibration& wave_cal, 
+ int slit_end_pos, int slit_begin_pos)
+{
+    int slit_mean_pos = slit_begin_pos + (slit_end_pos - slit_begin_pos) / 2;
+    int slit_pos_good_wavecal = -1;
+
+    //Try to find a slit position with valid wavelength calibration
+    //First from the middle to the top
+    for(int i_pos = slit_mean_pos; i_pos <= slit_end_pos; i_pos++)
+        if(wave_cal.has_valid_cal(i_pos))
+        {
+            slit_pos_good_wavecal = i_pos;
+            break;
+        }
+    //If not successful, try from the middle to the bottom
+    if(slit_pos_good_wavecal == -1)
+        for(int i_pos = slit_mean_pos; i_pos >= slit_begin_pos; i_pos--)
+            if(wave_cal.has_valid_cal(i_pos))
+            {
+                slit_pos_good_wavecal = i_pos;
+                break;
+            }
+    if(slit_pos_good_wavecal == -1)
+        throw std::runtime_error("Slit doesn't have any good wavelength calibration");
+    return slit_pos_good_wavecal ;    
+}
+
 const mosca::image& fors::flat_normaliser::get_normalisation_image() const
 {
     return m_normalisation_image;
@@ -515,3 +562,41 @@ cpl_image * fors::flat_normaliser::get_wave_profiles_im() const
     
     return wave_profiles_im;
 }
+
+cpl_image * fors::flat_normaliser::get_wave_profiles_im_mapped
+(const fors::detected_slits& det_slits,
+ const mosca::wavelength_calibration& wave_cal,
+ double firstLambda, double lastLambda, double dispersion) const
+{
+    int nl = (lastLambda - firstLambda) / dispersion;
+
+    cpl_image * mapped_flat_sed = 
+            cpl_image_new(nl, m_wave_profiles.size(), CPL_TYPE_FLOAT);
+    
+    for(size_t i_slit = 0; i_slit < det_slits.size(); ++i_slit)
+    {
+        int slit_begin_pos = 
+                det_slits[i_slit].get_position_spatial_corrected();
+        int slit_end_pos = slit_begin_pos +  
+                det_slits[i_slit].get_length_spatial_corrected();
+        
+        if(slit_begin_pos != -1)
+        {
+            int slit_pos_good_wavecal = fors::flat_normaliser::get_middle_slit_valid_calib
+                    (wave_cal, slit_end_pos, slit_begin_pos);
+            for(cpl_size i_wave = 0; i_wave < nl; ++i_wave)
+            {
+                int null;
+                double wave = firstLambda + i_wave * dispersion;
+                double pixel = wave_cal.get_pixel(slit_pos_good_wavecal, wave);
+                int i_pix = std::ceil(pixel+0.5);
+                if(i_pix>= 0 && i_pix <m_wave_profiles.front().size())
+                    cpl_image_set(mapped_flat_sed, i_wave+1, i_slit+1,
+                                  m_wave_profiles[i_slit][i_pix]);
+            }
+        }
+    }
+    
+    return mapped_flat_sed;
+}
+
