@@ -248,7 +248,7 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
     cpl_propertylist * sci_header = 
             cpl_propertylist_load(cpl_frame_get_filename(
                     cpl_frameset_get_position(sci_frame, 0)), 0);
-    mosca::fiera_config ccd_config(sci_header);    
+    fors::fiera_config ccd_config(sci_header);    
     cpl_propertylist_delete(sci_header);
     assure( !cpl_error_get_code(), return, "Could not get instrument setting" );
 
@@ -256,7 +256,7 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
     cpl_propertylist * master_bias_header =
        cpl_propertylist_load(cpl_frame_get_filename(
                cpl_frameset_get_position(master_bias_frame, 0)), 0);
-    fors_update_ccd_ron(ccd_config, master_bias_header);
+    fors::update_ccd_ron(ccd_config, master_bias_header);
     cpl_propertylist_delete(master_bias_header);
     assure( !cpl_error_get_code(), return, "Could not get RON from master bias"
             " (missing QC DET OUT? RON keywords)");
