@@ -234,7 +234,7 @@ fors_img_screen_flat(cpl_frameset *frames, const cpl_parameterlist *parameters)
     cpl_propertylist * sflat_header = 
             cpl_propertylist_load(cpl_frame_get_filename(
                     cpl_frameset_get_position(sflat_frames, 0)), 0);
-    mosca::fiera_config sflat_ccd_config(sflat_header);
+    fors::fiera_config sflat_ccd_config(sflat_header);
     cpl_propertylist_delete(sflat_header);
     assure( !cpl_error_get_code(), return, "Could not get instrument setting" );
 
@@ -242,7 +242,7 @@ fors_img_screen_flat(cpl_frameset *frames, const cpl_parameterlist *parameters)
     cpl_propertylist * master_bias_header =
        cpl_propertylist_load(cpl_frame_get_filename(
                cpl_frameset_get_position(master_bias_frame, 0)), 0);
-    fors_update_ccd_ron(sflat_ccd_config, master_bias_header);
+    fors::update_ccd_ron(sflat_ccd_config, master_bias_header);
     cpl_propertylist_delete(master_bias_header);
     assure( !cpl_error_get_code(), return, "Could not get RON from master bias");
 
