@@ -100,7 +100,7 @@ fors_image * fors_subtract_prescan(const fors_image * image,
         hdrl_parameter * port_region = por_reg.hdrl_param(); //deleted by por_reg
 
         hdrl_overscan_correct_result * os_correction =
-            hdrl_overscan_correct(target_image, port_region, 2, os_computation);
+            hdrl_overscan_correct(target_image, port_region, os_computation);
 
         hdrl_image * os_corrected_ima = 
             hdrl_overscan_correct_result_get_corrected(os_correction);
@@ -196,3 +196,18 @@ void fors_trimm_preoverscan(cpl_mask *& mask,
     mask = new_mask;
 }
 
+void fors_trimm_fill_info(cpl_propertylist * header,
+                          const mosca::ccd_config& ccd_config)
+{
+    mosca::rect_region crop_region = ccd_config.whole_valid_region();
+    mosca::rect_region crop_region_1 = crop_region.coord_0to1(); 
+
+    cpl_propertylist_append_int(header, "ESO QC TRIMM LLX",
+                                crop_region_1.llx());
+    cpl_propertylist_append_int(header, "ESO QC TRIMM LLY",
+                                crop_region_1.lly());
+    cpl_propertylist_append_int(header, "ESO QC TRIMM URX",
+                                crop_region_1.urx());
+    cpl_propertylist_append_int(header, "ESO QC TRIMM URY",
+                                crop_region_1.ury());
+}
