@@ -43,13 +43,13 @@ fors_image_load_preprocess(const cpl_frame *frame,
     /* Read the CCD configuration */
     const char * filename = cpl_frame_get_filename(frame);
     cpl_propertylist * header = cpl_propertylist_load(filename, 0) ;
-    mosca::fiera_config ccd_config(header);
+    fors::fiera_config ccd_config(header);
     if(!cpl_errorstate_is_equal(error_prevstate))
         return NULL;
     /* Update RON estimation from bias */
     cpl_propertylist * master_bias_header =
        cpl_propertylist_load(cpl_frame_get_filename(bias_frame), 0);
-    fors_update_ccd_ron(ccd_config, master_bias_header);
+    fors::update_ccd_ron(ccd_config, master_bias_header);
     cpl_propertylist_delete(master_bias_header);
     if(!cpl_errorstate_is_equal(error_prevstate))
         return NULL;
