@@ -41,6 +41,12 @@ cpl_table *fors_compute_response
  int nknots, int degree, cpl_table *& response_interp,
  double& flat_sed_norm_factor);
 
+void fors_science_correct_flat_sed_mapped
+(cpl_image *mapped_image,  cpl_table *objects,
+ cpl_image * mapped_flat_sed,
+ cpl_propertylist * flat_sed_header,
+ cpl_propertylist * specphot_header);
+
 CPL_END_DECLS
 
 #endif /* FORS_RESPONSE_H_ */
