@@ -36,7 +36,7 @@
 #include <fors_dfs.h>
 #include <fors_pfits.h>
 #include <fors_utils.h>
-#include "fiera_config.h"
+#include "fors_ccd_config.h"
 #include "fors_ccd_config.h"
 #include "fors_overscan.h"
 #include "fors_subtract_bias.h"
@@ -343,13 +343,13 @@ void fors_zeropoint(cpl_frameset *frames, const cpl_parameterlist *parameters)
         cleanup;
         return;
     }
-    mosca::fiera_config ccd_config(raw_header);
+    fors::fiera_config ccd_config(raw_header);
 
     /* Update RON estimation from bias */
     cpl_propertylist * master_bias_header =
        cpl_propertylist_load(cpl_frame_get_filename(
                cpl_frameset_get_position(master_bias_frame, 0)), 0);
-    fors_update_ccd_ron(ccd_config, master_bias_header);
+    fors::update_ccd_ron(ccd_config, master_bias_header);
     cpl_propertylist_delete(master_bias_header);
     assure( !cpl_error_get_code(), return, "Could not get RON from master bias"
             " (missing QC DET OUT? RON keywords)");
