@@ -51,7 +51,8 @@ cpl_bivector *mos_find_peaks(const float *, int, cpl_vector *,
                              cpl_polynomial *, double, int);
 double mos_eval_dds(cpl_polynomial *, double, double, double, double);
 cpl_polynomial *mos_poly_wav2pix(cpl_bivector *, int, double, int,
-                                 int *, double *);
+                                 int *, double *,
+                                 cpl_bivector **pixwav_used);
 cpl_polynomial *mos_poly_pix2wav(cpl_bivector *, int, double, int,
                                  int *, double *);
 cpl_image *mos_wavelength_calibration_raw(const cpl_image *image,
