@@ -78,7 +78,7 @@ test_image(void)
         create_standard_keys(header, exptime);
     }
 
-    fors_image_save(image, header, filename);
+    fors_image_save(image, header, NULL, filename);
     fors_image_delete(&image);
     cpl_frame_set_filename(frame, filename);
 
