@@ -135,7 +135,7 @@ test_stack(void)
         /* Save */
         master_filename = cpl_sprintf("stack_master_bias_%s.fits", method[i]);
         
-        fors_image_save(master, NULL, master_filename);
+        fors_image_save(master, NULL, NULL, master_filename);
         assure( !cpl_error_get_code(), return, 
                 "Error saving stacked image to %s", master_filename);
 
