@@ -1,7 +1,6 @@
-/* $Id: irplib_wlxcorr-test.c,v 1.16 2013-01-29 08:43:33 jtaylor Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2004 European Southern Observatory
+ * Copyright (C) 2001-2004,2014 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02111-1307  USA
  */
 
-/*
- * $Author: jtaylor $
- * $Date: 2013-01-29 08:43:33 $
- * $Revision: 1.16 $
- * $Name: not supported by cvs2svn $
- */
-
 /*-----------------------------------------------------------------------------
                                    Includes
  -----------------------------------------------------------------------------*/
@@ -42,14 +34,6 @@
 #include <math.h>
 #include <float.h>
 
-/* TEMPORARY SUPPORT OF CPL 5.x */
-#ifndef CPL_SIZE_FORMAT
-#define CPL_SIZE_FORMAT "d"
-#define cpl_size int
-#endif
-/* END TEMPORARY SUPPORT OF CPL 5.x */
-
-
 
 /*----------------------------------------------------------------------------*/
 /**
