@@ -39,6 +39,7 @@
 #include "hdrl_combine.h"
 #include "hdrl_elemop.h"
 #include "hdrl_prototyping.h"
+#include "hdrl_utils.h"
 
 #include <cpl.h>
 
@@ -62,13 +63,6 @@ static cpl_error_code hdrl_compute_flat(const cpl_imagelist *,
 static cpl_image * hdrl_medianclean_image(cpl_image *, cpl_size, cpl_size, 
         cpl_size, cpl_size);
 static cpl_image * hdrl_smooth_image_median(const cpl_image *, int);
-static cpl_matrix * hdrl_matrix_linspace(cpl_size, cpl_size, cpl_size);
-static cpl_matrix * hdrl_fit_legendre(cpl_image *, int, int, cpl_matrix *,
-        cpl_matrix *, cpl_size, cpl_size) ;
-static cpl_image * hdrl_legendre_to_image(cpl_matrix *, int, int,
-        cpl_size, cpl_size);
-static cpl_image * hdrl_medianfilter_image_grid(cpl_image *, cpl_matrix *,
-        cpl_matrix *, cpl_size, cpl_size);
 
 /** @cond PRIVATE */
 
@@ -560,173 +554,7 @@ static cpl_image * hdrl_smooth_image_median(
     return (out);
 }
 
-/* ---------------------------------------------------------------------------*/
-/**
- * @brief create linear space row vector
- * @param start  starting point
- * @param stop   end point, exclusive
- * @param step   step size
- *
- * @returns matrix with one row filled equally spaced points from start to end
- *
- */
-/* ---------------------------------------------------------------------------*/
-static cpl_matrix * hdrl_matrix_linspace(
-        cpl_size    start, 
-        cpl_size    stop, 
-        cpl_size    step)
-{
-    cpl_matrix * x = cpl_matrix_new(stop / step, 1);
-    for (intptr_t i = 0; start + i * step < stop && i < stop / step; i++) {
-        cpl_matrix_set(x, i, 0, start + i * step);
-    }
-    return x;
-}
 
-/* ---------------------------------------------------------------------------*/
-/**
- * @brief fit 2D legendre polynomials to img
- *
- * @param img      image to be fitted
- * @param order_x  order of x polynomial
- * @param order_y  order of y polynomial
- * @param grid_x   x grid to evaluate on
- * @param grid_y   y grid to evaluate on
- * @param orig_nx  upper limit in x, exclusive
- * @param orig_ny  upper limit in y, exclusive
- *
- * @return coefficient matrix of the fitted 2-D polynomial
- * @see hdrl_mime_linalg_pairwise_column_tensor_products_create,
- *      hdrl_legendre_to_image
- */
-/* ---------------------------------------------------------------------------*/
-static cpl_matrix * hdrl_fit_legendre(
-        cpl_image   *   img, 
-        int             order_x, 
-        int             order_y,
-        cpl_matrix  *   grid_x, 
-        cpl_matrix  *   grid_y,
-        cpl_size        orig_nx, 
-        cpl_size        orig_ny)
-{
-    cpl_size nx2 = cpl_matrix_get_nrow(grid_x);
-    cpl_size ny2 = cpl_matrix_get_nrow(grid_y);
-    cpl_matrix * xpolys =
-        hdrl_mime_legendre_polynomials_create(order_x + 1, 0, orig_nx - 1, grid_x);
-    cpl_matrix * ypolys =
-        hdrl_mime_legendre_polynomials_create(order_y + 1, 0, orig_ny - 1, grid_y);
-    cpl_matrix * tensors =
-        hdrl_mime_linalg_pairwise_column_tensor_products_create(ypolys,
-                                                                xpolys);
-    cpl_matrix * mimage = cpl_matrix_wrap(nx2 * ny2, 1, cpl_image_get_data(img));
-    cpl_matrix * coeffs = cpl_matrix_solve_normal(tensors, mimage);
-    cpl_msg_info(cpl_func, "%lld", cpl_matrix_get_nrow(coeffs));
-    cpl_matrix_unwrap(mimage);
-    cpl_matrix_delete(xpolys);
-    cpl_matrix_delete(ypolys);
-    cpl_matrix_delete(tensors);
-
-    return coeffs;
-}
-
-/* ---------------------------------------------------------------------------*/
-/**
- * @brief evaluate 2D legendre polynomials on image
- *
- * @param coeffs   legendre coefficients
- * @param order_x  order of x polynomial
- * @param order_y  order of y polynomial
- * @param nx       x size of image
- * @param ny       y size of image
- * @return legendre polynomial evaluated on an image
- *
- */
-/* ---------------------------------------------------------------------------*/
-static cpl_image * hdrl_legendre_to_image(
-        cpl_matrix  *   coeffs, 
-        int             order_x, 
-        int             order_y,
-        cpl_size        nx, 
-        cpl_size        ny)
-{
-    /* evaluate on full image */
-    /* TODO need grid of original fit here? */
-    cpl_matrix * x = hdrl_matrix_linspace(0, nx, 1);
-    cpl_matrix * y = hdrl_matrix_linspace(0, ny, 1);
-    cpl_matrix * xpolys =
-        hdrl_mime_legendre_polynomials_create(order_x + 1, 0, nx - 1, x);
-    cpl_matrix  * ypolys =
-        hdrl_mime_legendre_polynomials_create(order_y + 1, 0, ny - 1, y);
-    cpl_matrix * tensors =
-        hdrl_mime_linalg_pairwise_column_tensor_products_create(ypolys,
-                                                                xpolys);
-    cpl_matrix * result = cpl_matrix_product_create(tensors, coeffs);
-    cpl_image * iresult = cpl_image_wrap(nx, ny, CPL_TYPE_DOUBLE,
-                                         cpl_matrix_get_data(result));
-    cpl_matrix_delete(x);
-    cpl_matrix_delete(y);
-    cpl_matrix_delete(xpolys);
-    cpl_matrix_delete(ypolys);
-    cpl_matrix_delete(tensors);
-    cpl_matrix_unwrap(result);
-
-    return iresult;
-}
-
-/* ---------------------------------------------------------------------------*/
-/**
- * @brief filter image on a grid
- *
- * @param ima           image to filter
- * @param x             row vector of coordinates to filter on
- * @param y             row vector of coordinates to filter on
- * @param filtersize_x  size of the median filter
- * @param filtersize_y  size of the median filter
- * @return filtered image of size of the grid
- *
- */
-/* ---------------------------------------------------------------------------*/
-static cpl_image * hdrl_medianfilter_image_grid(
-        cpl_image   *   ima, 
-        cpl_matrix  *   x, 
-        cpl_matrix  *   y,
-        cpl_size        filtersize_x, 
-        cpl_size        filtersize_y)
-{
-    cpl_error_ensure(ima != NULL, CPL_ERROR_NULL_INPUT, return NULL, 
-            "NULL input image");
-    cpl_error_ensure(filtersize_x > 0 && filtersize_y > 0 , 
-            CPL_ERROR_INCOMPATIBLE_INPUT, return NULL,
-            "All function parameters must be greater then Zero");
-
-    const cpl_size nx = cpl_image_get_size_x(ima);
-    const cpl_size ny = cpl_image_get_size_y(ima);
-    const cpl_size steps_x = cpl_matrix_get_nrow(x);
-    const cpl_size steps_y = cpl_matrix_get_nrow(y);
-
-    cpl_image * ima_local = cpl_image_new(steps_x, steps_y, CPL_TYPE_DOUBLE);
-
-    for (cpl_size iy = 0; iy < steps_y; iy++) {
-        cpl_size middlep_y = cpl_matrix_get(y, iy, 0);
-        for (cpl_size ix = 0; ix < steps_x; ix++) {
-            cpl_size middlep_x = cpl_matrix_get(x, ix, 0);
-
-            cpl_size lowerlimit_x = CX_MAX(middlep_x - filtersize_x, 1);
-            cpl_size lowerlimit_y = CX_MAX(middlep_y - filtersize_y, 1);
-            cpl_size upperlimit_x = CX_MIN(middlep_x + filtersize_x, nx);
-            cpl_size upperlimit_y = CX_MIN(middlep_y + filtersize_y, ny);
-
-            double median = cpl_image_get_median_window(ima, lowerlimit_x,
-                            lowerlimit_y, upperlimit_x, upperlimit_y);
-
-            cpl_image_set(ima_local, ix + 1, iy + 1, median);
-
-            cpl_msg_debug(cpl_func, "middlep_x: %lld, middlep_y: %lld, median: "
-                          "%g", middlep_x, middlep_y, median);
-        }
-    }
-    return ima_local;
-}
 
 /**@}*/
 
