@@ -63,6 +63,8 @@ public:
 
     image(const image& other);
     
+    image& operator= (const image& other);
+    
     virtual ~image();
     
     inline cpl_size size_x() const;
@@ -104,6 +106,10 @@ public:
 
     cpl_image * get_cpl_image_err();
 
+    const cpl_image * get_cpl_image() const;
+
+    const cpl_image * get_cpl_image_err() const;
+
 private:
     
     void set_axis(axis dispersion_axis);
