@@ -791,13 +791,13 @@ static int fors_extract(cpl_parameterlist *parlist, cpl_frameset *frameset)
     cpl_msg_indent_more();
 
     if (!dfs_equal_keyword(frameset, "ESO INS GRIS1 ID"))
-        fors_extract_exit("Input frames are not from the same grism");
+        cpl_msg_warning(cpl_func,"Input frames are not from the same grism");
 
     if (!dfs_equal_keyword(frameset, "ESO INS FILT1 ID"))
-        fors_extract_exit("Input frames are not from the same filter");
+        cpl_msg_warning(cpl_func,"Input frames are not from the same filter");
 
     if (!dfs_equal_keyword(frameset, "ESO DET CHIP1 ID"))
-        fors_extract_exit("Input frames are not from the same chip");
+        cpl_msg_warning(cpl_func,"Input frames are not from the same chip");
 
     mxu = cpl_frameset_count_tags(frameset, "SCIENCE_MXU");
     mos = cpl_frameset_count_tags(frameset, "SCIENCE_MOS");
@@ -1675,7 +1675,9 @@ static int fors_extract(cpl_parameterlist *parlist, cpl_frameset *frameset)
         cpl_msg_info(recipe, "Object extraction...");
         cpl_msg_indent_more();
 
-        images = mos_extract_objects(mapped, skylocalmap, slits, 
+        //TODO: Add the real propagated variance here (the second argument)
+        //It should be done like in fors_science  
+        images = mos_extract_objects(mapped, NULL, skylocalmap, slits, 
                                      ext_mode, ron, gain, 1);
 
         cpl_image_delete(skylocalmap); skylocalmap = NULL;
