@@ -705,7 +705,7 @@ static int fors_normalise_flat(cpl_parameterlist *parlist,
             cpl_image_duplicate(master_flat.get_cpl_image()),
             cpl_image_power_create(master_flat.get_cpl_image_err(), 2.));
     fors_dfs_save_image_err(frameset, norm_flat,
-                            master_norm_flat_tag, header, parlist,
+                            master_norm_flat_tag, header, NULL, parlist,
                             recipe, master_flat_frame);
     if(cpl_error_get_code() != CPL_ERROR_NONE)
         fors_normalise_flat_exit(NULL);
@@ -715,11 +715,11 @@ static int fors_normalise_flat(cpl_parameterlist *parlist,
     cpl_image * wave_profiles = normaliser.get_wave_profiles_im();
     header = cpl_propertylist_new();
     cpl_propertylist_append_string(header, CPL_DFS_PRO_TYPE, "REDUCED");
-    cpl_propertylist_append_string(header, CPL_DFS_PRO_CATG, "FLAT_DISP_PROFILE") ;
+    cpl_propertylist_append_string(header, CPL_DFS_PRO_CATG, "FLAT_SED") ;
     cpl_dfs_save_image(frameset, NULL, parlist, frameset, 
                        master_flat_frame, wave_profiles, CPL_BPP_IEEE_FLOAT,
                        recipe, header, NULL, PACKAGE "/" PACKAGE_VERSION,  
-                       "flat_disp_profile.fits");
+                       "flat_sed.fits");
     if(cpl_error_get_code() != CPL_ERROR_NONE)
         fors_normalise_flat_exit(NULL);
     cpl_propertylist_delete(header); header = NULL;
