@@ -41,14 +41,14 @@
 #include "fors_ccd_config.h"
 #include "fors_overscan.h"
 #include "fors_subtract_bias.h"
-#include "fiera_config.h"
+#include "fors_ccd_config.h"
 
 static int fors_remove_bias_create(cpl_plugin *);
 static int fors_remove_bias_exec(cpl_plugin *);
 static int fors_remove_bias_destroy(cpl_plugin *);
 static int fors_remove_bias(cpl_parameterlist *, cpl_frameset *);
 
-static void fors_remove_bias_display_ccd_config(mosca::fiera_config &config);
+static void fors_remove_bias_display_ccd_config(fors::fiera_config &config);
 
 static char fors_remove_bias_description[] =
 "This recipe is used to subtract the overscan and master bias"
@@ -270,7 +270,7 @@ static int fors_remove_bias(cpl_parameterlist *parlist,
     }
 
     //Get master bias
-    std::auto_ptr<mosca::fiera_config> bias_ccd_config;  
+    std::auto_ptr<fors::fiera_config> bias_ccd_config;  
     if(nbias == 1)
     {
         cpl_msg_info(recipe, "Load master bias");
@@ -278,7 +278,7 @@ static int fors_remove_bias(cpl_parameterlist *parlist,
         bias_header = dfs_load_header(frameset, master_bias_tag, 0);
         cpl_frame * bias_frame = cpl_frameset_find(frameset, master_bias_tag);
 
-        bias_ccd_config.reset(new mosca::fiera_config(bias_header));
+        bias_ccd_config.reset(new fors::fiera_config(bias_header));
         master_bias = fors_image_load(bias_frame);
         
         if (master_bias == NULL)
@@ -309,12 +309,12 @@ static int fors_remove_bias(cpl_parameterlist *parlist,
                           target_raw_tag.c_str());
             fors_remove_bias_exit(NULL);
         }
-        mosca::fiera_config target_ccd_config(target_header);
+        fors::fiera_config target_ccd_config(target_header);
         cpl_propertylist_delete(target_header);
         fors_remove_bias_display_ccd_config(target_ccd_config);
 
         /* Update RON estimation from bias */
-        fors_update_ccd_ron(target_ccd_config, bias_header);
+        fors::update_ccd_ron(target_ccd_config, bias_header);
         
         //Check detector configs are the same as master bias
         if(nbias == 1)
@@ -366,7 +366,7 @@ static int fors_remove_bias(cpl_parameterlist *parlist,
     return 0;
 }
 
-static void fors_remove_bias_display_ccd_config(mosca::fiera_config &config)
+static void fors_remove_bias_display_ccd_config(fors::fiera_config &config)
 {
     for(size_t iport = 0; iport< config.nports(); ++iport)
     {
