@@ -485,7 +485,7 @@ static int fors_flat(cpl_parameterlist *parlist, cpl_frameset *frameset)
         const char * filename = cpl_frame_get_filename(flatframe);
         fors_image * flat_raw = fors_image_load(flatframe);
         cpl_propertylist * plist = cpl_propertylist_load(filename, 0) ;
-        mosca::fiera_config ccd_config(plist);
+        fors::fiera_config ccd_config(plist);
         if (!flat_raw)
             fors_flat_exit("Cannot load flat field");
         if(!cpl_errorstate_is_equal(error_prevstate))
@@ -494,7 +494,7 @@ static int fors_flat(cpl_parameterlist *parlist, cpl_frameset *frameset)
         /* Update RON estimation from bias */
         cpl_propertylist * master_bias_header =
            cpl_propertylist_load(cpl_frame_get_filename(bias_frame), 0);
-        fors_update_ccd_ron(ccd_config, master_bias_header);
+        fors::update_ccd_ron(ccd_config, master_bias_header);
         cpl_propertylist_delete(master_bias_header);
         if(!cpl_errorstate_is_equal(error_prevstate))
             fors_flat_exit("Could not get RON from master bias"
