@@ -436,10 +436,7 @@ static int fors_wave_calib_lss(cpl_parameterlist *parlist,
     int         mos;
     int         lss;
     int         treat_as_lss = 0;
-    int         nslits;
     double      mean_rms;
-    double     *xpos;
-    double      mxpos;
     int         narc;
     int         nlines;
     int         rebin;
@@ -590,13 +587,13 @@ static int fors_wave_calib_lss(cpl_parameterlist *parlist,
 
 
     if (!dfs_equal_keyword(frameset, "ESO INS GRIS1 ID"))
-        fors_wave_calib_lss_exit("Input frames are not from the same grism");
+        cpl_msg_warning(cpl_func,"Input frames are not from the same grism");
 
     if (!dfs_equal_keyword(frameset, "ESO INS FILT1 ID"))
-        fors_wave_calib_lss_exit("Input frames are not from the same filter");
+        cpl_msg_warning(cpl_func,"Input frames are not from the same filter");
 
     if (!dfs_equal_keyword(frameset, "ESO DET CHIP1 ID"))
-        fors_wave_calib_lss_exit("Input frames are not from the same chip");
+        cpl_msg_warning(cpl_func,"Input frames are not from the same chip");
 
 
     /*
