@@ -196,8 +196,9 @@ to the --ignore_lines recipe parameter."""
       tooltip_line_x_y ="""Detected/identified arc lines.
 Black points are detected lines. 
 Green points are identified lines.
-Light green points are identified lines after pattern-matching iteration
+Light green points are recovered identified lines after pattern-matching iteration
 (only if wradius >0).
+Red points are rejected lines in the wave vs pixel fit (only if wradius >0)
 Most detected lines should also be identified. 
 If lines at the edges are not identified this means that
 the dispersion relation there will be extrapolated."""
@@ -289,8 +290,7 @@ the dispersion relation there will be extrapolated."""
       paramList.append(reflex.RecipeParameter('fors_calib','fit_threshold',group='flat field norm',description='Threshold percentage for flat spline fitting with respect to the maximum'))
       paramList.append(reflex.RecipeParameter('fors_calib','stack_method',group='master flat',description='Frames combination method. <sum | mean | median | ksigma>'))
       paramList.append(reflex.RecipeParameter('fors_calib','kiter',group='master flat',description='Max number of iterations in ksigma method'))
-      paramList.append(reflex.RecipeParameter('fors_calib','klow',group='master flat',description='Low threshold in ksigma method'))
-      paramList.append(reflex.RecipeParameter('fors_calib','khigh',group='master flat',description='High threshold in ksigma method'))
+      paramList.append(reflex.RecipeParameter('fors_calib','ksigma',group='master flat',description='Low and high threshold in ksigma metho.'))
       paramList.append(reflex.RecipeParameter('fors_calib','slit_ident',group='master flat',description='Attempt slit identification for MOS or MXU'))
       paramList.append(reflex.RecipeParameter('fors_calib','startwavelength',group='wave calib / distorsions',description='Start wavelength in spectral extraction'))
       paramList.append(reflex.RecipeParameter('fors_calib','endwavelength',group='wave calib / distorsions',description='End wavelength in spectral extraction'))
@@ -329,7 +329,7 @@ if __name__ == '__main__':
   from fors_plot_common import *
 
   # Create interactive application
-  interactive_app = reflex_interactive_app.PipelineInteractiveApp()
+  interactive_app = reflex_interactive_app.PipelineInteractiveApp(enable_init_sop=True)
 
   #Check if import failed or not
   if import_sucess == 'false' :
