@@ -175,7 +175,6 @@ class PlotableMappedScience :
 
   def plot(self, subplot, title, tooltip):
     self.mappedsciencedisp.setLabels('X [pix]', 'Y [pix]')
-    self.mappedsciencedisp.setZLimits((0., 0.9))
     self.mappedsciencedisp.display(subplot, title, tooltip, self.mappedscience.image)
     if self.objecttable is not None:
       subplot.autoscale(enable=False)
@@ -269,6 +268,8 @@ class PlotableDetectedLines :
     self.wave_iter  = self.detectedlines.column
     self.detectedlines.readTableColumn(1, 'res_xpos')
     self.res_xpos  = self.detectedlines.column
+    self.detectedlines.readTableColumn(1, 'fit_used')
+    self.fit_used = self.detectedlines.column
 
   def plotXVsY(self, subplot, title, tooltip):
     #We first plot all the detected lines
